@@ -1,6 +1,6 @@
 ;;; elx.el --- Extract information from Emacs Lisp libraries  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2008-2026 Jonas Bernoulli
+;; Copyright (C) 2008-2025 Jonas Bernoulli
 
 ;; Includes code from Emacs, which is
 ;; Copyright (C) 1985-2022 Free Software Foundation, Inc.
@@ -9,8 +9,8 @@
 ;; Homepage: https://github.com/emacscollective/elx
 ;; Keywords: docs libraries packages
 
-;; Package-Version: 2.3.2
-;; Package-Revision: v2.3.2-0-g5c700de6d3b4
+;; Package-Version: 20251101.2004
+;; Package-Revision: 0fb0bc2c33a0
 ;; Package-Requires: (
 ;;     (emacs  "29.1")
 ;;     (compat "30.1")
@@ -50,6 +50,7 @@
 (require 'llama)
 (require 'package)
 (require 'seq)
+(require 'subr-x)
 
 (defgroup elx nil
   "Extract information from Emacs Lisp libraries."
@@ -178,11 +179,11 @@ single line, or the prefix used on continuation lines."
                  (elx--header-multiline "package-requires" t))))
     (and-let* ((lines lines)
                (value (funcall (cond
-                                 ((fboundp 'lm--prepare-package-dependencies)
-                                  'lm--prepare-package-dependencies)
-                                 ((fboundp 'package--prepare-dependencies)
-                                  'package--prepare-dependencies)
-                                 ((error "elx-package-requires: BUG")))
+                                ((fboundp 'lm--prepare-package-dependencies)
+                                 'lm--prepare-package-dependencies)
+                                ((fboundp 'package--prepare-dependencies)
+                                 'package--prepare-dependencies)
+                                ((error "elx-package-requires: BUG")))
                                (package-read-from-string
                                 (string-join lines " ")))))
       (if extra (list value beg end indent) value))))
@@ -1577,6 +1578,5 @@ single line, or the prefix used on continuation lines."
 (provide 'elx)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
-;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; elx.el ends here
